@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 ### after: use lib qw(@RT_LIB_PATH@);
-use lib qw(/Users/sunnavy/bps/git/rt/local/lib /Users/sunnavy/bps/git/rt/lib);
+use lib qw(/home/brad/BPS/work/rts/testing-mot-config-ui-older-rt/local/lib /home/brad/BPS/work/rts/testing-mot-config-ui-older-rt/lib);
 
 package RT::Extension::MandatoryOnTransition::Test;
 
